# -*- coding:utf-8; eval: (blacken-mode) -*-

import logging
import contextlib


logger = logging.getLogger(__name__)


def _init_logging():
    import logging.config

    cfg = {
        "version": 1,
        "formatters": {
            "standard": {
                "format": "%(asctime)s %(name)s %(levelname)s: %(message)s",
            }
        },
        "handlers": {
            "default": {
                "class": "logging.StreamHandler",
                "formatter": "standard",
                "stream": "ext://sys.stdout",
            }
        },
        "loggers": {
            "usadelndsoc": {
                "handlers": ["default"],
                "level": "INFO",
                "propagate": True,
            },
        },
    }

    logging.config.dictConfig(cfg)


class with_log_level(contextlib.ContextDecorator):
    def __init__(self, level, old_level=None):
        self._level = level
        self._old_level = old_level

    def __enter__(self):
        cm = with_log_level(self._level, int(logger.level))
        logger.setLevel(cm._level)
        return cm

    def __exit__(self, *exc):
        logger.setLevel(self._old_level)
        return False


_init_logging()
del _init_logging, logging, contextlib
